==> als-server_2.12-2.1.1-sources.jar: org/mulesoft/als/server/modules/actions/DocumentLinksManager.scala <==
package org.mulesoft.als.server.modules.actions

import java.util.UUID

import amf.core.remote.Platform
import org.mulesoft.als.actions.links.FindLinks
import org.mulesoft.als.server.RequestModule
import org.mulesoft.als.server.logger.Logger
import org.mulesoft.als.server.modules.ast.AstManager
import org.mulesoft.lsp.ConfigType
import org.mulesoft.lsp.feature.RequestHandler
import org.mulesoft.lsp.feature.link._
import org.mulesoft.lsp.feature.telemetry.TelemetryProvider

import scala.concurrent.ExecutionContext.Implicits.global
import scala.concurrent.Future

class DocumentLinksManager(val astManager: AstManager,
                           private val telemetryProvider: TelemetryProvider,
                           private val logger: Logger,
                           private val platform: Platform)
    extends RequestModule[DocumentLinkClientCapabilities, DocumentLinkOptions] {

  override val `type`: ConfigType[DocumentLinkClientCapabilities, DocumentLinkOptions] =
    DocumentLinkConfigType

  override val getRequestHandlers: Seq[RequestHandler[_, _]] = Seq(
    new RequestHandler[DocumentLinkParams, Seq[DocumentLink]] {
      override def `type`: DocumentLinkRequestType.type = DocumentLinkRequestType

      override def apply(params: DocumentLinkParams): Future[Seq[DocumentLink]] =
        documentLinks(params.textDocument.uri)
    }
  )

  override def applyConfig(config: Option[DocumentLinkClientCapabilities]): DocumentLinkOptions =
    DocumentLinkOptions(config.flatMap(_.dynamicRegistration))

  val onDocumentLinks: String => Future[Seq[DocumentLink]] = documentLinks

  def documentLinks(str: String): Future[Seq[DocumentLink]] =
    astManager
      .getCurrentAST(str, UUID.randomUUID().toString)
      .map(bu => FindLinks.getLinks(bu, platform))

  override def initialize(): Future[Unit] = Future.successful()

}

==> als-server_2.12-2.2.3-sources.jar: org/mulesoft/als/server/modules/actions/DocumentLinksManager.scala <==
package org.mulesoft.als.server.modules.actions

import java.util.UUID

import amf.core.remote.Platform
import org.mulesoft.als.actions.links.FindLinks
import org.mulesoft.als.server.RequestModule
import org.mulesoft.als.server.logger.Logger
import org.mulesoft.als.server.workspace.WorkspaceManager
import org.mulesoft.lsp.ConfigType
import org.mulesoft.lsp.feature.RequestHandler
import org.mulesoft.lsp.feature.link._
import org.mulesoft.lsp.feature.telemetry.TelemetryProvider
import org.mulesoft.lsp.server.LanguageServerSystemConf

import scala.concurrent.ExecutionContext.Implicits.global
import scala.concurrent.Future

class DocumentLinksManager(val workspaceManager: WorkspaceManager,
                           private val telemetryProvider: TelemetryProvider,
                           private val logger: Logger,
                           private val configuration: LanguageServerSystemConf)
    extends RequestModule[DocumentLinkClientCapabilities, DocumentLinkOptions] {

  override val `type`: ConfigType[DocumentLinkClientCapabilities, DocumentLinkOptions] =
    DocumentLinkConfigType

  override val getRequestHandlers: Seq[RequestHandler[_, _]] = Seq(
    new RequestHandler[DocumentLinkParams, Seq[DocumentLink]] {
      override def `type`: DocumentLinkRequestType.type = DocumentLinkRequestType

      override def apply(params: DocumentLinkParams): Future[Seq[DocumentLink]] =
        documentLinks(params.textDocument.uri)
    }
  )

  override def applyConfig(config: Option[DocumentLinkClientCapabilities]): DocumentLinkOptions =
    DocumentLinkOptions(config.flatMap(_.dynamicRegistration))

  val onDocumentLinks: String => Future[Seq[DocumentLink]] = documentLinks

  def documentLinks(str: String): Future[Seq[DocumentLink]] =
    workspaceManager
      .getUnit(str, UUID.randomUUID().toString)
      .flatMap(_.getLast)
      .map(bu => {
        FindLinks.getLinks(bu.unit, configuration.platform)
      })

  override def initialize(): Future[Unit] = Future.successful()

}
